DevToolsConfig class

DevTools configuration manager

Constructors

DevToolsConfig()
factory

Properties

currentBaseUrl → String
Getters
no setter
currentEnvironment → Environment?
Get current environment object
no setter
currentEnvironmentName → String
no setter
defaultEnvironment → Environment
Get default environment based on build mode
no setter
environments → List<Environment>
no setter
hashCode → int
The hash code for this object.
no setterinherited
isDevToolsEnabled → bool
Check if dev tools should be enabled
no setter
isDioLoggerEnabled → bool
no setter
isInitialized → bool
no setter
isNetworkAnalysisEnabled → bool
no setter
onReinitializeDio ↔ Future<void> Function()?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
theme → DevToolsTheme
no setter

Methods

getEnvironmentInfo() → Map<String, String>
Get environment info for display
init({Future<void> onReinitializeDio()?, List<Environment>? environments, List<Environment>? customEnvironments, bool enableInDebug = true, bool enableInProfile = true, bool enableInRelease = false}) → Future<void>
Initialize configuration from stored preferences
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetToDefault() → Future<void>
Reset to default configuration based on current build mode
setBaseUrl(String url) → Future<void>
Set base URL (will also try to match an environment)
setDioLoggerEnabled(bool enabled) → Future<void>
Toggle Dio logger
setEnvironment(Environment environment) → Future<void>
Set environment by name
setNetworkAnalysisEnabled(bool enabled) → Future<void>
Toggle network analysis
setTheme(DevToolsTheme theme) → void
Set custom theme for dev tools
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

buildMode → BuildMode
Build mode detection
no setter
buildModeString → String
Get build mode as string
no setter
isDebug → bool
no setter
isProfile → bool
no setter
isRelease → bool
no setter