DevToolsPreferences class

Internal storage helper for Dev Tools

Constructors

DevToolsPreferences()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getData({required String key}) → dynamic
Get data (returns dynamic, cast as needed)
init() → Future<void>
Initialize instances
remove({required String key}) → Future<bool>
saveData({required String key, required dynamic value}) → Future<bool>
Save data based on type