ExceptionLogger class

Constructors

ExceptionLogger()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
logs → List<ExceptionLogEntry>
no setter
maxLogs → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
clear() → void
logException(dynamic error, [StackTrace? stackTrace]) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeListener(VoidCallback listener) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited