AnalyticsEventLog class

Represents a logged analytics event

Constructors

AnalyticsEventLog({required DateTime timestamp, required String eventName, Map<String, dynamic>? parameters})

Properties

eventName → String
final
hashCode → int
The hash code for this object.
no setterinherited
parameters → Map<String, dynamic>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited