FirebaseDebugService class

Service for Firebase debugging features

Constructors

FirebaseDebugService()
factory

Properties

analyticsLog → List<AnalyticsEventLog>
Get analytics log (newest first)
no setter
hashCode → int
The hash code for this object.
no setterinherited
isCrashlyticsEnabled → bool
Check if Crashlytics collection is enabled
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Add a listener for updates
checkUnsentReports() → Future<bool>
Check for unsent reports
clearAnalyticsLog() → void
Clear analytics log
clearUserInfo() → Future<void>
Clear user info from both Analytics and Crashlytics
deleteUnsentReports() → Future<void>
Delete unsent reports
forceCrash() → void
Force a test crash (use with caution!)
logEvent({required String name, Map<String, dynamic>? parameters}) → Future<void>
Log an analytics event and track it
logScreenView({required String screenName, String? screenClass}) → Future<void>
Log screen view
logToCrashlytics(String message) → Future<void>
Log a message to Crashlytics
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recordError({required dynamic exception, StackTrace? stackTrace, String? reason, bool fatal = false}) → Future<void>
Record a non-fatal error
removeListener(VoidCallback listener) → void
Remove a listener
sendTestEvents() → Future<void>
Send predefined test events
sendUnsentReports() → Future<void>
Send unsent reports
setCrashlyticsCustomKey(String key, dynamic value) → Future<void>
Set custom key-value for Crashlytics
setCrashlyticsEnabled(bool enabled) → Future<void>
Enable/disable Crashlytics collection
setCrashlyticsUserId(String userId) → Future<void>
Set user identifier for Crashlytics
setUserId(String? userId) → Future<void>
Set user ID for analytics
setUserInfo({required String userId, String? email, String? name}) → Future<void>
Set user info for both Analytics and Crashlytics
setUserProperty({required String name, required String? value}) → Future<void>
Set user property
throwTestException() → Future<void>
Throw a test exception (non-fatal)
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited