NetworkLogEntry class

Represents a single network request log entry

Constructors

NetworkLogEntry({required String id, required DateTime timestamp, required String method, required String url, Map<String, dynamic>? requestHeaders, dynamic requestBody, int? statusCode, Map<String, dynamic>? responseHeaders, dynamic responseBody, Duration? duration, String? error, bool isCompleted = false})

Properties

duration → Duration?
final
error → String?
final
formattedRequestBody → String
Format response body for display
no setter
formattedResponseBody → String
no setter
hasError → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
isClientError → bool
no setter
isCompleted → bool
final
isServerError → bool
no setter
isSuccess → bool
Get status color based on status code
no setter
method → String
final
requestBody → dynamic
final
requestHeaders → Map<String, dynamic>?
final
responseBody → dynamic
final
responseHeaders → Map<String, dynamic>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int?
final
summary → String
Get request summary for list display
no setter
timestamp → DateTime
final
url → String
final

Methods

copyWith({int? statusCode, Map<String, dynamic>? responseHeaders, dynamic responseBody, Duration? duration, String? error, bool? isCompleted}) → NetworkLogEntry
Create a copy with updated values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited